# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

# (akien) No soname upstream, arbitrarily using 0 for now
# Without proper soname, the devel package would not generate the
# devel() provides that RPM relies on to pull in the proper deps
# in reverse dependencies.
%define major   0
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%define uname   SPIRV-Tools

# Comment out when using stable release.
# Upstream tracks git commits in their known_good.json, so we are forced to do the same.
# See glslang for the required known_good commit for this package.
%define git b27b1afd12d05bf238ac7368bb49de73cd620a8e
%define shortgit %(echo %{git} | cut -c1-7)
%define rel 1

Name:           spirv-tools
Version:        2020.6
# Check https://github.com/KhronosGroup/SPIRV-Tools/releases to see if any matches the commit,
# or take the last tag before the commit hash.
Release:        %mkrel %{rel}%{?git:.%{shortgit}}
Summary:        API and commands for processing SPIR-V modules
Group:          System/Libraries
License:        ASL 2.0
URL:            https://github.com/KhronosGroup/SPIRV-Tools
%if 0%{?git:1}
Source0:        https://github.com/KhronosGroup/SPIRV-Tools/archive/%{shortgit}/%{name}-%{shortgit}.tar.gz
%else
Source0:        https://github.com/KhronosGroup/SPIRV-Tools/archive/v%{version}/%{uname}-%{version}.tar.gz
%endif

Patch1:         spirv-tools-soversion.patch

# https://github.com/KhronosGroup/SPIRV-Tools/pull/3906
Patch2:         0001-CMake-FIx-pkg-config-libdir-with-absolute-CMAKE_INST.patch

BuildRequires:  cmake
BuildRequires:  python3
BuildRequires:  spirv-headers

%description
The package includes an assembler, binary module parser,
disassembler, and validator for SPIR-V.

%package -n %{libname}
Summary:        Library files for SPIR-V tools
Group:          System/Libraries
# Renamed during mga7 development
Obsoletes:      %{_lib}spirv-tools < 2018.6-3

%description -n %{libname}
Library files for SPIR-V tools.

%package -n %{devname}
Summary:        Development files for SPIR-V tools
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       spirv-headers
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for SPIR-V tools.

%prep
%autosetup -p1 -n %{uname}-%{!?git:%{version}}%{?git}

%build
%cmake \
    -DSPIRV_TOOLS_BUILD_STATIC=OFF \
    -DSPIRV_TOOLS_SOVERSION=%{major} \
    -DSPIRV_TOOLS_VERSION=%{version} \
    -DSPIRV-Headers_SOURCE_DIR=%{_prefix} \
    -DPYTHON_EXECUTABLE=%{__python3}
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md CHANGES
%{_bindir}/spirv-as
%{_bindir}/spirv-cfg
%{_bindir}/spirv-dis
%{_bindir}/spirv-lesspipe.sh
%{_bindir}/spirv-link
%{_bindir}/spirv-opt
%{_bindir}/spirv-reduce
%{_bindir}/spirv-val

%files -n %{libname}
%license LICENSE
%{_libdir}/lib%{uname}-{link,opt,reduce,shared}.so.%{major}
%{_libdir}/lib%{uname}-{link,opt,reduce,shared}.so.%{version}
%{_libdir}/lib%{uname}.so.%{major}
%{_libdir}/lib%{uname}.so.%{version}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/cmake/%{uname}{,-link,-opt,-reduce}/
%{_libdir}/pkgconfig/%{uname}-shared.pc
%{_libdir}/pkgconfig/%{uname}.pc
%{_libdir}/lib%{uname}-{link,opt,reduce,shared}.so
%{_libdir}/lib%{uname}.so


%changelog
* Wed Dec 30 2020 akien <akien> 2020.6-1.b27b1af.mga8
+ Revision: 1666494
- Version 2020.6, matching the requirements for Vulkan SDK 1.2.162.0

* Mon Oct 12 2020 akien <akien> 2020.5-1.b27e039.mga8
+ Revision: 1633972
- Version 2020.5
- Fix pkgconfig file

* Mon Feb 17 2020 akien <akien> 2020.1-1.323a81f.mga8
+ Revision: 1536924
- Commit 323a81f, known good for Vulkan SDK 1.2.131.2

* Sun Feb 16 2020 umeabot <umeabot> 2019.4-2.9b3cc3e.mga8
+ Revision: 1533956
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Sep 25 2019 akien <akien> 2019.4-1.9b3cc3e.mga8
+ Revision: 1445847
- Commit 9b3cc3e, known good for Vulkan SDK 1.1.121.0

* Thu Apr 18 2019 akien <akien> 2019.2-1.26c1b88.mga7
+ Revision: 1393158
- Commit 26c1b88 (2019.2+), matching requirements from Vulkan SDK 1.1.106.0

* Wed Mar 27 2019 akien <akien> 2019.1-2.b12e733.mga7
+ Revision: 1380635
- Update to git b12e733 required by glslang@5432f0d required by Vulkan SDK 1.1.101.1

* Tue Mar 26 2019 akien <akien> 2019.1-1.mga7
+ Revision: 1380468
- Version 2019.1

* Tue Dec 11 2018 akien <akien> 2018.6-3.mga7
+ Revision: 1340201
- Properly libify with defined soname (major 0 for now)

* Tue Dec 11 2018 akien <akien> 2018.6-2.mga7
+ Revision: 1340187
- Development package should require spirv-headers

* Mon Dec 10 2018 akien <akien> 2018.6-1.mga7
+ Revision: 1339742
- Adapt to Mageia policies
- import spirv-tools from Fedora Rawhide

